# forwarg

forwarg is a drop-in replacement for Python's argparse module, used to parse
command-line arguments. forwarg is designed to make it easier to forward the
arguments to another command, allowing to manipulate them through special
objects. forwarg implements the same API as argparse, but it has been written
from scratch.

## License

forwarg is distributed under the terms of the
[GNU General Public License v3.0](http://www.gnu.org/copyleft/gpl.html)
(see LICENSE).
